==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/ResourceGuardProxyBaseArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property description
 * @property lastUpdatedTime
 * @property resourceGuardOperationDetails
 * @property resourceGuardResourceId
 */
public data class ResourceGuardProxyBaseArgs(
    public val description: Output<String>? = null,
    public val lastUpdatedTime: Output<String>? = null,
    public val resourceGuardOperationDetails: Output<List<ResourceGuardOperationDetailArgs>>? = null,
    public val resourceGuardResourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs =
        com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .lastUpdatedTime(lastUpdatedTime?.applyValue({ args0 -> args0 }))
            .resourceGuardOperationDetails(
                resourceGuardOperationDetails?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .resourceGuardResourceId(resourceGuardResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceGuardProxyBaseArgs].
 */
@PulumiTagMarker
public class ResourceGuardProxyBaseArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var lastUpdatedTime: Output<String>? = null

    private var resourceGuardOperationDetails: Output<List<ResourceGuardOperationDetailArgs>>? = null

    private var resourceGuardResourceId: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("lgdevjwbwdvsajad")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value
     */
    @JvmName("ippjerxrkworjksb")
    public suspend fun lastUpdatedTime(`value`: Output<String>) {
        this.lastUpdatedTime = value
    }

    /**
     * @param value
     */
    @JvmName("ojopckiipswcopsw")
    public suspend
    fun resourceGuardOperationDetails(`value`: Output<List<ResourceGuardOperationDetailArgs>>) {
        this.resourceGuardOperationDetails = value
    }

    @JvmName("helyplybpxtikwqp")
    public suspend fun resourceGuardOperationDetails(
        vararg
        values: Output<ResourceGuardOperationDetailArgs>,
    ) {
        this.resourceGuardOperationDetails = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("mqordxtheiracuvg")
    public suspend
    fun resourceGuardOperationDetails(values: List<Output<ResourceGuardOperationDetailArgs>>) {
        this.resourceGuardOperationDetails = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("khdaukolrhatiqxi")
    public suspend fun resourceGuardResourceId(`value`: Output<String>) {
        this.resourceGuardResourceId = value
    }

    /**
     * @param value
     */
    @JvmName("vksswrkqpjbidvux")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value
     */
    @JvmName("tqlvikpyknfycxgt")
    public suspend fun lastUpdatedTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastUpdatedTime = mapped
    }

    /**
     * @param value
     */
    @JvmName("iyohybwpvekvpwmg")
    public suspend
    fun resourceGuardOperationDetails(`value`: List<ResourceGuardOperationDetailArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("wbnihkdpwgenvqkj")
    public suspend
    fun resourceGuardOperationDetails(argument: List<suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("qkuqdokvyfujkdtg")
    public suspend fun resourceGuardOperationDetails(
        vararg
        argument: suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("avoifajunruhausy")
    public suspend
    fun resourceGuardOperationDetails(argument: suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param values
     */
    @JvmName("sukmtwarnfglxrov")
    public suspend fun resourceGuardOperationDetails(
        vararg
        values: ResourceGuardOperationDetailArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param value
     */
    @JvmName("rofoerdpgwbwtpew")
    public suspend fun resourceGuardResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardResourceId = mapped
    }

    internal fun build(): ResourceGuardProxyBaseArgs = ResourceGuardProxyBaseArgs(
        description = description,
        lastUpdatedTime = lastUpdatedTime,
        resourceGuardOperationDetails = resourceGuardOperationDetails,
        resourceGuardResourceId = resourceGuardResourceId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/ResourceGuardProxyBaseArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property description
 * @property lastUpdatedTime
 * @property resourceGuardOperationDetails
 * @property resourceGuardResourceId
 */
public data class ResourceGuardProxyBaseArgs(
    public val description: Output<String>? = null,
    public val lastUpdatedTime: Output<String>? = null,
    public val resourceGuardOperationDetails: Output<List<ResourceGuardOperationDetailArgs>>? = null,
    public val resourceGuardResourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs =
        com.pulumi.azurenative.recoveryservices.inputs.ResourceGuardProxyBaseArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .lastUpdatedTime(lastUpdatedTime?.applyValue({ args0 -> args0 }))
            .resourceGuardOperationDetails(
                resourceGuardOperationDetails?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .resourceGuardResourceId(resourceGuardResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceGuardProxyBaseArgs].
 */
@PulumiTagMarker
public class ResourceGuardProxyBaseArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var lastUpdatedTime: Output<String>? = null

    private var resourceGuardOperationDetails: Output<List<ResourceGuardOperationDetailArgs>>? = null

    private var resourceGuardResourceId: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("ckuoscknqisrmdbe")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value
     */
    @JvmName("cnclgrhulvxmrpgj")
    public suspend fun lastUpdatedTime(`value`: Output<String>) {
        this.lastUpdatedTime = value
    }

    /**
     * @param value
     */
    @JvmName("tvbkghwtxqyynojl")
    public suspend
    fun resourceGuardOperationDetails(`value`: Output<List<ResourceGuardOperationDetailArgs>>) {
        this.resourceGuardOperationDetails = value
    }

    @JvmName("hwuwgrogixjhldxp")
    public suspend fun resourceGuardOperationDetails(
        vararg
        values: Output<ResourceGuardOperationDetailArgs>,
    ) {
        this.resourceGuardOperationDetails = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("smvpjuwqfhwypgos")
    public suspend
    fun resourceGuardOperationDetails(values: List<Output<ResourceGuardOperationDetailArgs>>) {
        this.resourceGuardOperationDetails = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("mxbggomoaqgdygxp")
    public suspend fun resourceGuardResourceId(`value`: Output<String>) {
        this.resourceGuardResourceId = value
    }

    /**
     * @param value
     */
    @JvmName("fpxtksmlcompjivj")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value
     */
    @JvmName("fhlwnrdsetewfyre")
    public suspend fun lastUpdatedTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastUpdatedTime = mapped
    }

    /**
     * @param value
     */
    @JvmName("ijgtwqbkqsbrbmml")
    public suspend
    fun resourceGuardOperationDetails(`value`: List<ResourceGuardOperationDetailArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("xiveftkhejfvshph")
    public suspend
    fun resourceGuardOperationDetails(argument: List<suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("nhxypasrrilgcmoy")
    public suspend fun resourceGuardOperationDetails(
        vararg
        argument: suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("nuyybraqnhivxqhk")
    public suspend
    fun resourceGuardOperationDetails(argument: suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param values
     */
    @JvmName("ieosqakcrjcuaqwr")
    public suspend fun resourceGuardOperationDetails(
        vararg
        values: ResourceGuardOperationDetailArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param value
     */
    @JvmName("bitskswdthscbjfx")
    public suspend fun resourceGuardResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardResourceId = mapped
    }

    internal fun build(): ResourceGuardProxyBaseArgs = ResourceGuardProxyBaseArgs(
        description = description,
        lastUpdatedTime = lastUpdatedTime,
        resourceGuardOperationDetails = resourceGuardOperationDetails,
        resourceGuardResourceId = resourceGuardResourceId,
    )
}
